@@ -13,19 +13,18 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-activation.c 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #include "config.h"
 
 #include "ephy-activation.h"
 
+#include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-session.h"
 #include "ephy-prefs.h"
-#include "eel-gconf-extensions.h"
 #include "ephy-debug.h"
 
 static gboolean
@@ -64,8 +63,12 @@ ephy_activation_load_uri_list (EphyDbus *ephy_dbus,
 			       guint startup_id,
 			       GError **error)
 {
+	char *new_options;
+	
+	new_options = g_strconcat (options, "external,", NULL);
 	return session_queue_command (EPHY_SESSION_CMD_OPEN_URIS,
-				      options, uris, startup_id, error);
+				      new_options, uris, startup_id, error);
+	g_free (new_options);
 }
 
 gboolean
@@ -83,7 +86,8 @@ ephy_activation_open_bookmarks_editor (EphyDbus *ephy_dbus,
 				       guint startup_id,
 				       GError **error)
 {
-	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING))
+	if (g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
+				    EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING))
 	{
 		g_set_error (error,
 			     g_quark_from_static_string ("ephy-activation-error"),
